betty.gramps package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gramps package

## Submodules

- betty.gramps.error module
  - `GrampsError`
  - `UserFacingGrampsError`
- betty.gramps.loader module
  - `GrampsEntityReference`
    - `GrampsEntityReference.__init__()`
    - `GrampsEntityReference.entity_id`
    - `GrampsEntityReference.entity_type`
  - `GrampsEntityType`
    - `GrampsEntityType.CITATION`
    - `GrampsEntityType.EVENT`
    - `GrampsEntityType.OBJECT`
    - `GrampsEntityType.PERSON`
    - `GrampsEntityType.SOURCE`
  - `GrampsFileNotFound`
  - `GrampsLoader`
    - `GrampsLoader.__init__()`
    - `GrampsLoader.load_file()`
    - `GrampsLoader.load_gpkg()`
    - `GrampsLoader.load_gramps()`
    - `GrampsLoader.load_xml()`
  - `LoaderUsedAlready`
  - `XPathError`

## Module contents

Integrate Betty with Gramps.